<?php
/**
 * CT Amulet functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package CT_AMULET
 */

if ( ! defined( 'CT_AMULET_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'CT_AMULET_VERSION', '3.0' );
}

if ( ! function_exists( 'ct_amulet_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function ct_amulet_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on CT Amulet, use a find and replace
		 * to change 'ct-amulet' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'ct-amulet', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'ct-amulet' ),
				'top'	 => esc_html__( 'Top', 'ct-amulet' )
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'ct_amulet_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Custom Image Sizes
		add_image_size('ct_amulet_thumb','500','400',true);


		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 300,
				'width'       => 120,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'ct_amulet_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function ct_amulet_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'ct_amulet_content_width', 640 );
}
add_action( 'after_setup_theme', 'ct_amulet_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function ct_amulet_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'ct-amulet' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'ct-amulet' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 1', 'ct-amulet' ),
			'id'            => 'footer-1',
			'description'   => esc_html__( 'Add widgets here.', 'ct-amulet' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 2', 'ct-amulet' ),
			'id'            => 'footer-2',
			'description'   => esc_html__( 'Add widgets here.', 'ct-amulet' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 3', 'ct-amulet' ),
			'id'            => 'footer-3',
			'description'   => esc_html__( 'Add widgets here.', 'ct-amulet' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'ct_amulet_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function ct_amulet_scripts() {
	wp_enqueue_style( 'ct-amulet-style', get_stylesheet_uri(), array(), CT_AMULET_VERSION );
	wp_style_add_data( 'ct-amulet-style', 'rtl', 'replace' );

	wp_enqueue_style('dashicons');

	wp_enqueue_style('ct-amulet-fonts', 'https://fonts.googleapis.com/css?family=Manrope:400,700', array(), CT_AMULET_VERSION);

	wp_enqueue_style('ct-amulet-main-css', get_template_directory_uri() . '/assets/css/main.css', array(), CT_AMULET_VERSION);

	wp_enqueue_script('ct-amulet-custom-js', get_template_directory_uri() . '/assets/js/custom.js', array(), CT_AMULET_VERSION, true);

	wp_enqueue_script( 'ct-amulet-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), CT_AMULET_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'ct_amulet_scripts' );

function ct_amulet_admin_scripts() {

	wp_enqueue_media();
	wp_enqueue_script( 'ct-amulet-gallery-js', get_template_directory_uri() . '/assets/js/custom-gallery.js', array('jquery'), CT_AMULET_VERSION, true );

}
add_action( 'admin_enqueue_scripts','ct_amulet_admin_scripts' );


/**
 *	Custom Colors
 */
function ct_amulet_custom_css() {

	$accent = get_theme_mod('ct-amulet-primary-color', '#309eb7');
	$link_clr = get_theme_mod('ct-amulet-link-color', '#777777');
	$link_hvr = get_theme_mod('ct-amulet-link-hover', '#000');
	$link_actv = get_theme_mod('ct-amulet-link-active', '#000');
	$link_vst = get_theme_mod('ct-amulet-link-visited', '#000');
	$nav_link_clr = get_theme_mod('ct-amulet-nav-link-color', '#000');
	$nav_link_hvr = get_theme_mod('ct-amulet-nav-link-hover', '#000');
	$nav_dd_bg = get_theme_mod('ct-amulet-nav-dd-bg-color', '#fafafa');
	$top_bar_bg = get_theme_mod('ct-amulet-top-bg', '#fafafa');
	$footer_bg = get_theme_mod('ct-amulet-footer-bg', '#309eb7');
	$footer_text = get_theme_mod('ct-amulet-footer-text-color', '#ffffff');
	$footer_link = get_theme_mod('ct-amulet-footer-link-color', '#ffffff');

	$output = '';
	$output .= ':root {
		--accent: ' . $accent . ';
		--link: ' . $link_clr . ';
		--link-hover: ' . $link_hvr . ';
		--link-active: ' . $link_actv . ';
		--link-visited: ' . $link_vst . ';
		--nav-link: ' . $nav_link_clr . ';
		--nav-link-hover: ' . $nav_link_hvr . ';
		--nav-dd-bg: ' . $nav_dd_bg . ';
		--top-bar-bg: ' . $top_bar_bg . ';
		--footer-bg: ' . $footer_bg . ';
		--footer-text: ' . $footer_text . ';
		--footer-link: ' . $footer_link . ';

		}';

	$overlay = get_theme_mod('ct_amulet_header_overlay_enable', 1);

	if ( !empty( $overlay ) ) {
		$output .= '#masthead.banner #header-wrapper:before {

				content: "";
				position: absolute;
				left: 0;
				top: 0;
				right: 0;
				bottom: 0;
				background-color: rgba(0,0,0,0.35);
		}';
	}

	wp_add_inline_style( 'ct-amulet-main-css', $output );

}
add_action( 'wp_enqueue_scripts', 'ct_amulet_custom_css' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 *	Footer Sidebar
 */
require get_template_directory() . '/inc/footer-sidebar.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';
require get_template_directory() . '/inc/customizer/extend-customizer.php';

/**
 *	Walker for Navigation Menu
 */
require get_template_directory() . '/inc/walker.php';

/**
 *	Block Styles for the theme
 */
 require get_template_directory() . '/inc/block-styles.php';

 /**
  *	Include TGM Plugin Activation
  */
  require get_template_directory() . '/inc/tgmpa.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}
