<?php
/**
 * CT Amulet Theme Customizer
 *
 * @package ct_amulet
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function ct_amulet_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'ct_amulet_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'ct_amulet_customize_partial_blogdescription',
			)
		);
	}

	$wp_customize->add_section(
		'ct_amulet_single_layout', array(
			'title'		=>	__('Single Post', 'ct-amulet'),
			'priority'	=>	50
		)
	);

	$wp_customize->add_setting(
		'ct_amulet_fimage_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_amulet_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_amulet_fimage_enable', array(
			'label'		=>	__('Show Featured Image', 'ct-amulet'),
			'type'		=>	'checkbox',
			'section'	=> 'ct_amulet_single_layout',
		)
	);

	$wp_customize->add_setting(
		'ct_amulet_single_date_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_amulet_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_amulet_single_date_enable', array(
			'label'		=>	__('Show Date', 'ct-amulet'),
			'type'		=>	'checkbox',
			'section'	=> 'ct_amulet_single_layout',
		)
	);

	$wp_customize->add_setting(
		'ct_amulet_single_author_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_amulet_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_amulet_single_author_enable', array(
			'label'		=>	__('Show Author', 'ct-amulet'),
			'type'		=>	'checkbox',
			'section'	=> 'ct_amulet_single_layout',
		)
	);

	$wp_customize->add_setting(
		'ct_amulet_single_cats_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_amulet_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_amulet_single_cats_enable', array(
			'label'		=>	__('Show Categories (Post Footer)', 'ct-amulet'),
			'type'		=>	'checkbox',
			'section'	=> 'ct_amulet_single_layout',
		)
	);

	$wp_customize->add_setting(
		'ct_amulet_single_tags_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_amulet_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_amulet_single_tags_enable', array(
			'label'		=>	__('Show Tags (Post Footer)', 'ct-amulet'),
			'type'		=>	'checkbox',
			'section'	=> 'ct_amulet_single_layout',
		)
	);

	$wp_customize->add_setting(
		'ct_amulet_single_nav_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_amulet_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_amulet_single_nav_enable', array(
			'label'		=>	__('Show Post Navigation', 'ct-amulet'),
			'type'		=>	'checkbox',
			'section'	=> 'ct_amulet_single_layout',
		)
	);



	function ct_amulet_sanitize_social( $input ) {
		$social_networks = array(
					'none' ,
					'facebook-alt',
					'twitter',
					'instagram',
					'pinterest',
					'mail',
					'rss',
					'youtube',
					'twitch',
					'xing'
				);
		if ( in_array($input, $social_networks) )
			return $input;
		else
			return '';
	}

	$wp_customize->add_panel(
		'ct_amulet_theme_options', array(
			'title'			=>	__('Theme Options', 'ct-amulet'),
			'priority'		=>	30
		)
	);

	$wp_customize->add_section(
		'ct_amulet_general_options', array(
		'title'		=>	__('General', 'ct-amulet'),
		'panel'		=>	'ct_amulet_theme_options',
		'priority'	=>	50
		)
	);

	$wp_customize->add_setting(
		'ct_amulet_mobile_menu_btn_text', array(
			'default'		=>	__('MENU', 'ct-amulet'),
			'sanitize_callback'	=>	'sanitize_text_field',
			'transport'		=>	'postMessage'
		)
	);

	$wp_customize->add_control(
		'ct_amulet_mobile_menu_btn_text', array(
			'label'		=>	__('Mobile Menu Button Text', 'ct-amulet'),
			'priority'	=>	10,
			'section'	=>	'ct_amulet_general_options'
		)
	);

	$wp_customize->add_setting(
		'ct_amulet_site_layout', array(
			'default'		=>	__('container', 'ct-amulet'),
			'sanitize_callback'	=>	'ct_amulet_sanitize_radio'
		)
	);

	$wp_customize->add_control(
		'ct_amulet_site_layout', array(
			'label'		=>	__('Site Layout', 'ct-amulet'),
			'type'		=>	'radio',
			'section'	=>	'ct_amulet_general_options',
			'choices'	=>	array(
				'container'		=>	__('Boxed layout', 'ct-amulet'),
				'container-fluid'	=>	__('Full Width Layout', 'ct-amulet')
			)
		)
	);
}
add_action( 'customize_register', 'ct_amulet_customize_register' );

/**
 *	Sanitization of Checkbox
 */
 function ct_amulet_sanitize_checkbox( $input ) {
    if ( $input == 1 ) {
        return 1;
    } else {
        return '';
    }
}

//Sanitization of Select
function ct_amulet_sanitize_select( $input, $setting ) {

    //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
    $input = sanitize_key($input);

    //get the list of possible select options
    $choices = $setting->manager->get_control( $setting->id )->choices;

    //return input if valid or return default option
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

}

//Sanitization of Radio
function ct_amulet_sanitize_radio( $input, $setting ) {

	// Ensure input is a slug
	$input = sanitize_key( $input );

	// Get list of choices from the control
	// associated with the setting
	$choices = $setting->manager->get_control( $setting->id )->choices;

	// If the input is a valid key, return it;
	// otherwise, return the default
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function ct_amulet_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function ct_amulet_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 *	Add Modules for Customizer Controls
 */
 require_once get_template_directory() . '/inc/customizer/top-bar.php';
 require_once get_template_directory() . '/inc/customizer/header.php';
 require_once get_template_directory() . '/inc/customizer/colors.php';
 require_once get_template_directory() . '/inc/customizer/footer.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function ct_amulet_customize_preview_js() {
	wp_enqueue_script( 'ct-amulet-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), CT_AMULET_VERSION, true );
}
add_action( 'customize_preview_init', 'ct_amulet_customize_preview_js' );
