<?php
/**
 *  Customizer Controls for the Top Bar
 */

function ct_amulet_top_bar_customize_register( $wp_customize ) {

    $wp_customize->add_panel(
		'ct_amulet_top_bar', array(
			'title'		=>	__('Top Bar', 'ct-amulet'),
			'priority'	=>	50
		)
	);

    //General
    $wp_customize->add_section(
        'ct_amulet_top_general', array(
            'title'     =>  __('General', 'ct-amulet'),
            'panel'     => 'ct_amulet_top_bar',
            'priority'  =>  2
        )
    );

    $wp_customize->add_setting(
        'ct_amulet_top_bar_enable', array(
            'default'               =>  '',
            'sanitize_callback'    =>  'ct_amulet_sanitize_checkbox'
        )
    );

    $wp_customize->add_control(
        'ct_amulet_top_bar_enable', array(
            'label'     =>  __('Enable Top Bar', 'ct-amulet'),
            'type'      =>  'checkbox',
            'section'   =>  'ct_amulet_top_general',
            'priority'  =>  5
        )
    );

    $wp_customize->add_setting(
        'ct_amulet_btn_text', array(
            'default'               =>  'Important Links',
            'sanitize_callback'    =>  'sanitize_text_field'
        )
    );

    $wp_customize->add_control(
        'ct_amulet_btn_text', array(
            'label'     =>  __('Label for Navigation Button in Phones', 'ct-amulet'),
            'section'   =>  'ct_amulet_top_general',
            'priority'  =>  10
        )
    );

    $wp_customize->add_setting(
		'ct-amulet-top-bg', array(
			'default'	=>	'#fafafa',
			'sanitize_callback'	=>	'sanitize_hex_color',
            'transport'          =>  'postMessage'
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, 'ct-amulet-top-bg', array(
				'label'		=>	esc_html__('Top Bar Background Color', 'ct-amulet'),
				'section'	=>	'ct_amulet_top_general',
				'settings'	=>	'ct-amulet-top-bg'
			)
		)
	);

    //Content
    $wp_customize->add_section(
        'ct_amulet_top_content', array(
            'title'     =>  __('Content', 'ct-amulet'),
            'panel'     => 'ct_amulet_top_bar',
            'priority'  =>  5
        )
    );

    $wp_customize->add_setting(
        'ct_amulet_top_content', array(
            'default'               =>  '',
            'sanitize_callback'    =>  'sanitize_textarea_field'
        )
    );

    $wp_customize->add_control(
        'ct_amulet_top_content', array(
            'label'     =>  __('Content', 'ct-amulet'),
            'type'      =>  'textarea',
            'section'   =>  'ct_amulet_top_content',
            'priority'  =>  5
        )
    );

    //Social Icons
    $wp_customize->add_section('ct_amulet_social_section', array(
			'title' 	=> esc_html__('Social Icons','ct-amulet'),
            'panel'     => 'ct_amulet_top_bar',
			'priority' 	=> 10
	));

	$wp_customize->add_setting(
		'ct_amulet_social_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'ct_amulet_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'ct_amulet_social_enable', array(
			'label'	=>	__('Show Social Icons in Header', 'ct-amulet'),
			'type'	=>	'checkbox',
			'section'	=>	'ct_amulet_social_section',
			'priority'	=>	5
		)
	);

	$social_networks = array( //Redefinied in Sanitization Function.
					'none'         => esc_html__('-','ct-amulet'),
					'facebook-alt' => esc_html__('Facebook', 'ct-amulet'),
					'twitter'      => esc_html__('Twitter', 'ct-amulet'),
					'instagram'    => esc_html__('Instagram', 'ct-amulet'),
                    'pinterest'    => esc_html__('Pinterest', 'ct-amulet'),
                    'mail'         => esc_html__('Mail', 'ct-amulet'),
					'rss'          => esc_html__('RSS Feeds', 'ct-amulet'),
					'youtube'      => esc_html__('Youtube', 'ct-amulet'),
					'twitch'       => esc_html__('Twitch', 'ct-amulet'),
					'xing'         => esc_html__('Xing', 'ct-amulet')
				);


    $social_count = count($social_networks);

	for ($s = 1 ; $s <= ($social_count - 3) ; $s++) :

		$wp_customize->add_setting(
			'ct_amulet_social_' . $s, array(
				'sanitize_callback' => 'ct_amulet_sanitize_social',
				'default' 			=> 'none',
			));

		$wp_customize->add_control( 'ct_amulet_social_' . $s, array(
					'settings' 	=> 'ct_amulet_social_' . $s,
					'label' 	=> esc_html__('Icon ','ct-amulet') . $s,
					'section' 	=> 'ct_amulet_social_section',
					'type' 		=> 'select',
					'choices' 	=> $social_networks,
		));

		$wp_customize->add_setting(
			'ct_amulet_social_url'.$s, array(
				'sanitize_callback' => 'esc_url_raw'
			));

		$wp_customize->add_control( 'ct_amulet_social_url' . $s, array(
			'label' 		=> esc_html__('Icon ','ct-amulet') . $s . esc_html__(' Url','ct-amulet'),
					'settings' 		=> 'ct_amulet_social_url' . $s,
					'section' 		=> 'ct_amulet_social_section',
					'type' 			=> 'url',
					'choices' 		=> $social_networks,
		));

	endfor;

}
add_action('customize_register', 'ct_amulet_top_bar_customize_register');
