<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package CT_AMULET
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function ct_amulet_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'ct_amulet_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function ct_amulet_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'ct_amulet_pingback_header' );

/**
 *  Top Search
 */
function ct_amulet_header_search_form() { ?>

	<div id="ct_amulet_search">
		<button class="jump-to-field" tabindex="-1"></button>
	    <?php get_search_form(); ?>
	</div>
<?php
}

function ct_amulet_search_form( $form ) {
    $form = '<form role="search" method="get" id="searchform" class="searchform" action="' . home_url( '/' ) . '" >
    <label class="screen-reader-text" for="s">' . __( 'Search for:', 'ct-amulet' ) . '</label>
    <input type="text" value="' . get_search_query() . '" name="s" id="s" />
	<button type="submit" id="searchsubmit" />
           <span class="dashicons dashicons-search"></span>
      </button>
    </form>';

    return $form;
}
add_filter( 'get_search_form', 'ct_amulet_search_form' );


/**
 *	Post Excerpt
 */
 function ct_amulet_excerpt($post = NULL, $limit = 40) {

	if (NULL == $post ) {
		global $post;
	}

	 $output	=	'';

	 if ( isset($post->ID) && has_excerpt($post->ID) ) {
		 $output = $post->post_excerpt;
	 }

	 elseif ( isset( $post->post_content ) ) {
		if ( strpos($post->post_content, '<!--more-->') ) {
			$output	=	get_the_content('');
		}
		else {
			$output	=	wp_trim_words( strip_shortcodes( $post->post_content ), $limit );
		}
	}
	return $output;
 }

 /**
  *	Top Navigation
  */
  function ct_amulet_top_nav() {
	  require_once get_template_directory() . '/inc/modules/top-nav.php';
  }

 /**
  * Top Bar Area
  */
 function ct_amulet_top_bar() {

	 if ( empty( get_theme_mod('ct_amulet_top_bar_enable') ) ) {
		 return;
	 }

	  ?>
	  <div id="ct-top-bar">
		  <div class="container">

			 <?php
			 ct_amulet_top_nav();

			 if ( get_theme_mod('ct_amulet_top_content', '') != '' ) {	 ?>

		  	<div id="top-content" class="col-auto">
				<p>
					<?php echo esc_html( get_theme_mod('ct_amulet_top_content', '') ); ?>
				</p>
				<button type="button" class="top-content-toggle"><span class="dashicons dashicons-arrow-down-alt2"></span></button>
			</div>

			<?php
			}

			get_template_part( 'inc/social' ); ?>
		</div>
	  </div>
 	<?php
 }


 /**
  *	Main navigation Module
  */
 function ct_amulet_navigation() {
	 ?>
	 <button id="go-to-end" class="nav-jumper" tabindex="-1"></button>
	 <nav id="site-navigation" class="main-navigation">
		 <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><?php echo esc_html( get_theme_mod('ct_amulet_mobile_menu_btn_text', 'MENU') ); ?></button>
		 <?php
		 wp_nav_menu(
			 array(
				 'theme_location' => 'menu-1',
				 'menu_id'        => 'primary-menu',
				 'walker'		 =>	has_nav_menu('menu-1') ? new ct_amulet_Mobile_Menu : '',
			 )
		 );
		 ?>
	 </nav><!-- #site-navigation -->
	 <button id="go-to-top" class="nav-jumper" tabindex="-1"></button>
	 <?php
 }

/**
 *	Function for Masthead of the Theme
**/
function ct_amulet_masthead( $masthead = 'classic', $layout = 'container' ) {
	switch ( $masthead ) :

		case 'basic':

		ct_amulet_top_bar();
		?>

		<header id="masthead" class="site-header basic <?php echo esc_attr( $layout ) ?>">
			<div id="header-wrapper">
				<div class="site-branding">
					<?php
					the_custom_logo(); ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>

						<?php
					$ct_amulet_description = get_bloginfo( 'description', 'display' );
					if ( $ct_amulet_description || is_customize_preview() ) :
						?>
						<p class="site-description"><?php echo $ct_amulet_description; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>
					<?php endif; ?>
				</div><!-- .site-branding -->


				<?php
				//ct_amulet_header_search_form();
				// Navigation
				ct_amulet_navigation();
				?>

			</div>

		</header><!-- #masthead -->

		<?php
		break;

		case 'classic':

		ct_amulet_top_bar();
		?>

		<header id="masthead" class="site-header classic <?php echo esc_attr( $layout ) ?>">
			<div id="header-wrapper">
				<div class="site-branding">
					<?php
					the_custom_logo(); ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>

						<?php
					$ct_amulet_description = get_bloginfo( 'description', 'display' );
					if ( $ct_amulet_description || is_customize_preview() ) :
						?>
						<p class="site-description"><?php echo $ct_amulet_description; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>
					<?php endif; ?>
				</div><!-- .site-branding -->


				<?php ct_amulet_header_search_form(); ?>

			</div>

			<?php
					the_header_image_tag();

			// Navigation
			ct_amulet_navigation();
			?>

		</header><!-- #masthead -->

		<?php
		break;

		case 'banner':

		ct_amulet_top_bar();
		?>

		<header id="masthead" class="site-header banner">
			<div id="header-wrapper">
				<div class="<?php echo esc_attr( $layout ) ?>">
					<div class="site-branding">
						<?php
						the_custom_logo(); ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>

							<?php
						$ct_amulet_description = get_bloginfo( 'description', 'display' );
						if ( $ct_amulet_description || is_customize_preview() ) :
							?>
							<p class="site-description"><?php echo $ct_amulet_description; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>
						<?php endif; ?>
					</div><!-- .site-branding -->
				</div><!-- .container -->
			</div>

			<div class="container">
				<?php
					// Navigation
					ct_amulet_navigation();
				?>
			</div>

		</header><!-- #masthead -->

		<?php
		break;

		default:

		ct_amulet_top_bar();
		?>

		<header id="masthead" class="site-header <?php echo esc_attr( $layout ) ?>">
		<div id="header-wrapper">
			<div class="site-branding">
				<?php
				the_custom_logo(); ?>
					<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>

					<?php
				$ct_amulet_description = get_bloginfo( 'description', 'display' );
				if ( $ct_amulet_description || is_customize_preview() ) :
					?>
					<p class="site-description"><?php echo $ct_amulet_description; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>
				<?php endif; ?>
			</div><!-- .site-branding -->

			<?php ct_amulet_header_search_form(); ?>

		</div>

		<?php
			if ( is_front_page() ) :
				the_header_image_tag();
			endif;

		ct_amulet_navigation();
		?>

		</header><!-- #masthead -->

	<?php
	endswitch;
}

function ct_amulet_footer_sidebar() { ?>
	<div id="footer-sidebar">
		<div class="container">
			<?php for( $i = 1; $i <= 3; $i++ ) { ?>
				<div class="footer footer-<?php echo esc_attr( $i ) ?>">
					<?php if ( !is_active_sidebar('footer-' . esc_attr( $i ))) return;?>
					<?php dynamic_sidebar('footer-' . $i) ?>
				</div>
			<?php } ?>
		</div>
	</div>
<?php
}
